@@ -422,6 +422,12 @@ gcm_prefs_add_profiles_suitable_for_devices (CcColorPanel *prefs,
       if (!ret)
         continue;
 
+#if CD_CHECK_VERSION(0,1,13)
+      /* ignore profiles from other user accounts */
+      if (!cd_profile_has_access (profile_tmp))
+        continue;
+#endif
+
       /* add */
       gcm_prefs_combobox_add_profile (widget,
                                       profile_tmp,
@@ -476,7 +482,7 @@ gcm_prefs_profile_remove_cb (GtkWidget *widget, CcColorPanel *prefs)
                                                "treeview_devices"));
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
   if (!gtk_tree_selection_get_selected (selection, &model, &iter))
-    g_assert_not_reached ();
+    goto out;
 
   /* if the profile is default, then we'll have to make the first profile default */
   gtk_tree_model_get (model, &iter,
@@ -573,6 +579,7 @@ gcm_prefs_profile_view_cb (GtkWidget *widget, CcColorPanel *prefs)
   g_ptr_array_add (argv, g_strdup (cd_profile_get_id (profile)));
   g_ptr_array_add (argv, g_strdup ("--parent-window"));
   g_ptr_array_add (argv, g_strdup_printf ("%i", xid));
+  g_ptr_array_add (argv, NULL);
   ret = g_spawn_async (NULL, (gchar**) argv->pdata, NULL, 0,
                        NULL, NULL, NULL, &error);
   if (!ret)
@@ -889,6 +896,7 @@ gcm_prefs_profile_clicked (CcColorPanel *prefs, CdProfile *profile, CdDevice *de
 {
   GtkWidget *widget;
   CdDeviceRelation relation;
+  gchar *s;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* get profile */
@@ -919,7 +927,13 @@ gcm_prefs_profile_clicked (CcColorPanel *prefs, CdProfile *profile, CdDevice *de
   /* allow getting profile info */
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
                "toolbutton_profile_view"));
-  gtk_widget_set_sensitive (widget, TRUE);
+  if ((s = g_find_program_in_path ("gcm-viewer")))
+    {
+      gtk_widget_set_sensitive (widget, TRUE);
+      g_free (s);
+    }
+  else
+      gtk_widget_set_sensitive (widget, FALSE);
 
   /* hide device specific stuff */
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
@@ -1350,7 +1364,7 @@ gcm_prefs_get_profile_title (CcColorPanel *prefs, CdProfile *profile)
   title = cd_profile_get_title (profile);
   if (title != NULL)
     {
-      string = g_strdup (title);
+      string = g_markup_escape_text (title, -1);
       goto out;
     }
 
@@ -1501,6 +1515,16 @@ gcm_prefs_device_set_model_by_iter (CcColorPanel *prefs, CdDevice *device, GtkTr
       goto out;
     }
 
+#if CD_CHECK_VERSION(0,1,13)
+      /* ignore profiles from other user accounts */
+      if (!cd_profile_has_access (profile))
+        {
+          g_warning ("%s is not usable by this user",
+                     cd_profile_get_filename (profile));
+          goto out;
+        }
+#endif
+
   /* autogenerated printer defaults */
   if (cd_device_get_kind (device) == CD_DEVICE_KIND_PRINTER &&
       cd_profile_get_filename (profile) == NULL)
