@@ -568,19 +568,20 @@ query_done (GFile        *file,
 
   self->priv->cancellable = NULL;
   info = g_file_query_filesystem_info_finish (file, res, &error);
-  if (info == NULL)
+  if (info != NULL)
+    {
+      self->priv->total_bytes += g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_SIZE);
+      g_object_unref (info);
+    }
+  else
     {
       char *path;
       path = g_file_get_path (file);
       g_warning ("Failed to get filesystem free space for '%s': %s", path, error->message);
       g_free (path);
       g_error_free (error);
-      return;
     }
 
-  self->priv->total_bytes += g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_SIZE);
-  g_object_unref (info);
-
   /* And onto the next element */
   get_primary_disc_info_start (self);
 }
@@ -1137,14 +1138,21 @@ info_panel_setup_hostname (CcInfoPanel  *self,
 {
   char *str;
   GtkWidget *entry;
+  GError *error = NULL;
+
+  if (permission == NULL)
+    {
+      g_debug ("Will not show hostname, hostnamed not installed");
+      return;
+    }
 
   entry = WID ("name_entry");
 
-  gtk_widget_show (WID ("label4"));
-  gtk_widget_show (entry);
-
   if (g_permission_get_allowed (permission) != FALSE)
-    gtk_widget_set_sensitive (entry, TRUE);
+    {
+      g_debug ("Not allowed to change the hostname");
+      gtk_widget_set_sensitive (entry, TRUE);
+    }
 
   self->priv->hostnamed_proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
                                                                G_DBUS_PROXY_FLAGS_NONE,
@@ -1153,11 +1161,19 @@ info_panel_setup_hostname (CcInfoPanel  *self,
                                                                "/org/freedesktop/hostname1",
                                                                "org.freedesktop.hostname1",
                                                                NULL,
-                                                               NULL);
+                                                               &error);
 
   /* This could only happen if the policy file was installed
    * but not hostnamed, which points to a system bug */
-  g_assert (self->priv->hostnamed_proxy);
+  if (self->priv->hostnamed_proxy == NULL)
+    {
+      g_debug ("Couldn't get hostnamed to start, bailing: %s", error->message);
+      g_error_free (error);
+      return;
+    }
+
+  gtk_widget_show (WID ("label4"));
+  gtk_widget_show (entry);
 
   str = info_panel_get_hostname (self);
   if (str != NULL)
@@ -1182,7 +1198,6 @@ info_panel_setup_overview (CcInfoPanel  *self)
 
   permission = polkit_permission_new_sync ("org.freedesktop.hostname1.set-static-hostname", NULL, NULL, NULL);
   /* Is hostnamed installed? */
-  if (permission != NULL)
     info_panel_setup_hostname (self, permission);
 
   res = load_gnome_version (&self->priv->gnome_version,
@@ -1307,7 +1322,8 @@ on_pk_get_tid_ready (GObject      *source,
   result = g_dbus_proxy_call_finish (G_DBUS_PROXY (source), res, &error);
   if (result == NULL)
     {
-      g_warning ("Error getting PackageKit transaction ID: %s", error->message);
+      if (g_error_matches (error, G_DBUS_ERROR, G_DBUS_ERROR_SERVICE_UNKNOWN) == FALSE)
+        g_warning ("Error getting PackageKit transaction ID: %s", error->message);
       g_error_free (error);
       return;
     }
