@@ -205,19 +205,24 @@ get_primary_device_cb (GObject *source_object, GAsyncResult *res, gpointer user_
   UpDeviceKind kind;
   UpDeviceState state;
   GIcon *icon;
+  GtkWidget *status_box;
   CcPowerPanelPrivate *priv = CC_POWER_PANEL (user_data)->priv;
 
+  status_box = GTK_WIDGET (gtk_builder_get_object (priv->builder,
+                                                   "hbox_status"));
+
   result = g_dbus_proxy_call_finish (G_DBUS_PROXY (source_object), res, &error);
   if (result == NULL)
     {
-      g_printerr ("Error getting primary device: %s\n", error->message);
+      if (g_strstr_len (error->message, -1, "no primary device") == NULL)
+        g_printerr ("Error getting primary device: %s\n", error->message);
       g_error_free (error);
-      widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
-                                                   "hbox_status"));
-      gtk_widget_hide (widget);
+      gtk_widget_hide (status_box);
       return;
     }
 
+  gtk_widget_show (status_box);
+
   /* set the icon and text */
   g_variant_get (result,
                  "((susdut))",
@@ -383,6 +388,7 @@ combo_time_changed_cb (GtkWidget *widget, CcPowerPanel *self)
   gint value;
   gboolean ret;
   const gchar *key = (const gchar *)g_object_get_data (G_OBJECT(widget), "_gsettings_key");
+  gchar *key_timeout;
 
   /* no selection */
   ret = gtk_combo_box_get_active_iter (GTK_COMBO_BOX(widget), &iter);
@@ -395,8 +401,11 @@ combo_time_changed_cb (GtkWidget *widget, CcPowerPanel *self)
                       1, &value,
                       -1);
 
-  /* set both battery and ac keys */
-  g_settings_set_int (self->priv->gsd_settings, key, value);
+  /* set both keys */
+  key_timeout = g_strdup_printf ("%s-timeout", key);
+  g_settings_set_int (self->priv->gsd_settings, key_timeout, value);
+  g_settings_set_boolean (self->priv->gsd_settings, key, value != 0);
+  g_free (key_timeout);
 }
 
 static void
@@ -537,14 +546,11 @@ set_ac_battery_ui_mode (CcPowerPanel *self)
   g_ptr_array_unref (devices);
 out:
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
-                                               "vbox_actions"));
+                                               "box_header"));
   gtk_widget_set_visible (widget, has_batteries);
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
-                                               "vbox_battery"));
+                                               "combobox_sleep_battery"));
   gtk_widget_set_visible (widget, has_batteries);
-  widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
-                                               "hbox_ac"));
-  gtk_widget_set_visible (widget, !has_batteries);
 }
 
 static void
@@ -552,7 +558,6 @@ cc_power_panel_init (CcPowerPanel *self)
 {
   GError     *error;
   GtkWidget  *widget;
-  GtkWidget  *target;
   gint        value;
 
   self->priv = POWER_PANEL_PRIVATE (self);
@@ -595,70 +600,12 @@ cc_power_panel_init (CcPowerPanel *self)
                     G_CALLBACK (on_lock_settings_changed),
                     self);
 
-  /* setup the checkboxes correcty */
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep_ac"));
-  target = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_sleep_ac"));
-  g_object_bind_property (widget, "active",
-                          target, "sensitive",
-                          G_BINDING_SYNC_CREATE);
-  gtk_widget_set_sensitive (widget,
-                            up_client_get_can_suspend (self->priv->up_client));
-
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep_battery"));
-  target = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_sleep_battery"));
-  g_object_bind_property (widget, "active",
-                          target, "sensitive",
-                          G_BINDING_SYNC_CREATE);
-  gtk_widget_set_sensitive (widget,
-                            up_client_get_can_suspend (self->priv->up_client));
-
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep"));
-  target = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_sleep"));
-  g_object_bind_property (widget, "active",
-                          target, "sensitive",
-                          G_BINDING_SYNC_CREATE);
-  gtk_widget_set_sensitive (widget,
-                            up_client_get_can_suspend (self->priv->up_client));
-
-  /* bind the checkboxes */
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep_ac"));
-  g_settings_bind (self->priv->gsd_settings,
-                   "sleep-inactive-ac",
-                   widget, "active",
-                   G_SETTINGS_BIND_DEFAULT);
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep_battery"));
-  g_settings_bind (self->priv->gsd_settings,
-                   "sleep-inactive-battery",
-                   widget, "active",
-                   G_SETTINGS_BIND_DEFAULT);
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "checkbutton_sleep"));
-  g_settings_bind (self->priv->gsd_settings,
-                   "sleep-inactive-ac",
-                   widget, "active",
-                   G_SETTINGS_BIND_DEFAULT);
-
   /* auto-sleep time */
   value = g_settings_get_int (self->priv->gsd_settings, "sleep-inactive-ac-timeout");
   widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
                                                "combobox_sleep_ac"));
   set_value_for_combo (GTK_COMBO_BOX (widget), value);
-  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "sleep-inactive-ac-timeout");
-  g_signal_connect (widget, "changed",
-                    G_CALLBACK (combo_time_changed_cb),
-                    self);
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_sleep"));
-  set_value_for_combo (GTK_COMBO_BOX (widget), value);
-  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "sleep-inactive-ac-timeout");
+  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "sleep-inactive-ac");
   g_signal_connect (widget, "changed",
                     G_CALLBACK (combo_time_changed_cb),
                     self);
@@ -666,7 +613,7 @@ cc_power_panel_init (CcPowerPanel *self)
   widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
                                                "combobox_sleep_battery"));
   set_value_for_combo (GTK_COMBO_BOX (widget), value);
-  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "sleep-inactive-battery-timeout");
+  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "sleep-inactive-battery");
   g_signal_connect (widget, "changed",
                     G_CALLBACK (combo_time_changed_cb),
                     self);
@@ -682,26 +629,6 @@ cc_power_panel_init (CcPowerPanel *self)
                     G_CALLBACK (combo_enum_changed_cb),
                     self);
 
-  value = g_settings_get_enum (self->priv->gsd_settings, "button-power");
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_button_power"));
-  disable_unavailable_combo_items (self, GTK_COMBO_BOX (widget));
-  set_value_for_combo (GTK_COMBO_BOX (widget), value);
-  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "button-power");
-  g_signal_connect (widget, "changed",
-                    G_CALLBACK (combo_enum_changed_cb),
-                    self);
-
-  value = g_settings_get_enum (self->priv->gsd_settings, "button-sleep");
-  widget = GTK_WIDGET (gtk_builder_get_object (self->priv->builder,
-                                               "combobox_button_sleep"));
-  disable_unavailable_combo_items (self, GTK_COMBO_BOX (widget));
-  set_value_for_combo (GTK_COMBO_BOX (widget), value);
-  g_object_set_data (G_OBJECT(widget), "_gsettings_key", "button-sleep");
-  g_signal_connect (widget, "changed",
-                    G_CALLBACK (combo_enum_changed_cb),
-                    self);
-
   widget = WID (self->priv->builder, "vbox_power");
   gtk_widget_reparent (widget, (GtkWidget *) self);
 }
