@@ -253,9 +253,8 @@ get_brightness_cb (GObject *source_object, GAsyncResult *res, gpointer user_data
     {
       gtk_widget_hide (WID ("screen_brightness_hscale"));
       gtk_widget_hide (WID ("screen_auto_reduce_checkbutton"));
-      /* FIXME: This needs a proper fix:
-       * https://bugzilla.gnome.org/show_bug.cgi?id=657606 */
-      gtk_label_set_text (GTK_LABEL (WID ("brightness-section-heading")), "");
+      gtk_widget_hide (WID ("brightness-frame"));
+      g_object_set (G_OBJECT (WID ("turn-off-alignment")), "left-padding", 0, NULL);
       g_warning ("Error getting brightness: %s", error->message);
       g_error_free (error);
       return;
@@ -535,6 +534,7 @@ cc_screen_panel_init (CcScreenPanel *self)
 
   widget = WID ("screen_vbox");
   gtk_widget_reparent (widget, (GtkWidget *) self);
+  g_object_set (self, "valign", GTK_ALIGN_START, NULL);
 }
 
 void
